

# class AiInputs:
#
#     def __init__(self,
#                  file_path: str | None = None,
#                  prompt: str | None = None,
#                 ):
#         self.file_path = file_path
#         self.prompt = prompt
